@@ -20,10 +20,13 @@ from lxml import etree
 from svg_ultralight.string_conversion import set_attributes
 
 if TYPE_CHECKING:
-    from lxml.etree import _Element as EtreeElement  # type: ignore
+    from lxml.etree import QName
+    from lxml.etree import (
+        _Element as EtreeElement,  # pyright: ignore[reportPrivateUsage]
+    )
 
 
-def new_element(tag: str, **attributes: str | float) -> EtreeElement:
+def new_element(tag: str | QName, **attributes: str | float) -> EtreeElement:
     """Create an etree.Element, make every kwarg value a string.
 
     :param tag: element tag
@@ -59,7 +62,7 @@ def new_element(tag: str, **attributes: str | float) -> EtreeElement:
 
 
 def new_sub_element(
-    parent: EtreeElement, tag: str, **attributes: str | float
+    parent: EtreeElement, tag: str | QName, **attributes: str | float
 ) -> EtreeElement:
     """Create an etree.SubElement, make every kwarg value a string.
 
@@ -103,6 +106,7 @@ def deepcopy_element(elem: EtreeElement, **attributes: str | float) -> EtreeElem
         "deepcopy_element is deprecated. "
         + "Use copy.deepcopy from the standard library instead.",
         category=DeprecationWarning,
+        stacklevel=1,
     )
     elem = copy.deepcopy(elem)
     _ = update_element(elem, **attributes)
